# -*- coding: utf-8 -*-
#CPE 1704 TKS
"""
Standard Manupilation modules that are not directly UI based.
"""
import math
from PyQt4.QtCore import QRect
from PyQt4 import QtGui as QtGui 


def Enhance(self, im, name, lo, hi):
# set up the image
    im=curIm
    self.enhancer = enhancer(im)
    self.update("1.0") # normalize

    self.value = eval(value)
        
def ScaleLabel(self, xW, yH, w, h):
    """
    Send widget x(Width), y(Height) of center point
    and h,w of image passed.
    """
    return QRect(xW-int(w/2), yH-int(h/2), w, h)


def pil2qpixmap(pil_image):
    try:
        w, h = pil_image.size
        data = pil_image.tostring("raw", "BGRX")
        qimage = QtGui.QImage(data, w, h, QtGui.QImage.Format_RGB32)
        qpixmap = QtGui.QPixmap(w,h)
        pix = QtGui.QPixmap.fromImage(qimage)
        return pix
    except:
            print "Error: No Photo to load"
        
def valToScalar(value, range=20):
    """
    Calculates an appropiate value to scale from / to
    """
    if value is None:
        return 1
    else:
        if (value >0):
            return 1+value/float(range)
        if (value <0):
            return 1+(value*(1/float(range)))
        if (value ==0):
            return 1
            

def convertImSize(core, origW,  origH,  wConstraint,  hConstraint,  rotation=0,  sizeMutable=0):
    """
        FIXME:  Replaced for Exif orientation 
        ##core.valOrient == 0 or
        SizeMutable allows for the swapping of height and width for thumbnail rotations
    """
    widgetRatio = float(wConstraint)/float(hConstraint)
    imageRatio = float(origW)/float(origH)

    if (imageRatio >= widgetRatio): #landscape 
        scale=origW/float(wConstraint)
        newW=wConstraint
        newH=int(math.ceil(origH/scale))
    else: # portrait
        if (sizeMutable==1):
            scale=origH/float(wConstraint)
            newH=wConstraint
            newW=int(math.ceil(origW/scale))
        else:
            scale=origH/float(hConstraint)
            newH=hConstraint
            newW=int(math.ceil(origW/scale))
    return newW,  newH
